@@ -4,21 +4,26 @@ import uuid
 
 from asyncio import Queue, Event
 
+
 def generate_session_id():
     return str(uuid.uuid4())
 
+
 class Entry:
     def __init__(self, text: str = None, image_url: str = None):
         self.text = text
         self.image_url = image_url
 
+
 class BotEntry(Entry):
     pass
 
+
 class UserEntry(Entry):
     pass
 
-class ConversationState(object):
+
+class ConversationState:
     def __init__(self, output_callback):
         self.output_callback = output_callback
         self.session_id: str = generate_session_id()
@@ -60,9 +65,12 @@ class ConversationState(object):
         return user_input
 
     def last_user_input(self) -> ta.Optional[str]:
-        last_user_input = next(filter(lambda e: isinstance(e, UserEntry), reversed(self.log)), None)
+        last_user_input = next(
+            filter(lambda e: isinstance(e, UserEntry), reversed(self.log)), None
+        )
         if last_user_input:
             return last_user_input.text
+        return None
 
     def set_out_of_context_handler(self, handler: ta.Callable):
         self.out_of_context_handlers.append(handler)
@@ -78,16 +86,20 @@ class ConversationState(object):
         await self._bot_wait_for_input_event.wait()
         self._bot_wait_for_input_event.clear()
 
-class OutOfContext(object):
+
+class OutOfContext:
     def __init__(self, state, handler):
         self.state = state
         self.state.set_out_of_context_handler(handler)
+
     def __enter__(self):
         return self.state
+
     def __exit__(self, type, value, traceback):
         self.state.pop_out_of_context_handler()
 
-class TerminationState(object):
-    def __init__(self, success=True):
+
+class Outputs:
+    def __init__(self, success=True, **kwargs):
         self.success = success
-        self.failure = not success
\ No newline at end of file
+        self.outputs = kwargs
